==> segment-wrapper-2.33.0.tgz: package/README.md <==
# Segment Wrapper [![Build Status](https://travis.mpi-internal.com/scmspain/frontend-all--segment-wrapper.svg?token=rg6VMzkvzMeJr1v4tr6s&branch=master)](https://travis.mpi-internal.com/scmspain/frontend-all--segment-wrapper) ![](https://img.shields.io/badge/automatic-release-brightgreen)

This package adds an abstraction layer on top of [segment.com](https://segment.com/)'s [javascript library](https://segment.com/docs/sources/website/analytics.js/) with some useful integrations and fixes that could be used across Adevinta Spain:

**Data Quality 📈**
- [x] Add `page` method that internally uses `track` but with the correct `referrer` property.
- [x] Send `user.id` and `anonymousId` on every track.

**Adobe Audience Manager DMP 🙋**
- [x] Integrates DMP and send `ssf` correct value depending on user's consents.
- [x] Sync Facebook and Google pixels (if you provide the needed config).
- [x] Persist pixels to sync in a stack, to be sure they're sent after navigation.
- [x] Send md5 hashed email with normalizations via `userEmail` or `hashedUserEmail` configs.

**Adobe Marketing Cloud Visitor Id ☁️**
- [x] Load *Adobe Visitor API* when needed.
- [x] Fetch `marketingCloudVisitorId` and put in integrations object for every track.
- [x] Monkey patch `track` native Segment method to send `marketingCloudVisitorId` inside `context.integrations`.

**Consent Management Platform 🐾**
- [x] Automatic tracking of Consent Management Platform usage.
- [x] Send `gdpr_privacy` on `context` for for all tracking events. Expect values: `unknown`, `accepted` and `declined`. 

**Developer Experience 👩‍💻**
- [x] Always send `platform` property as `web`.
- [x] Allow to configure `window.__mpi.defaultProperties` to send these properties on all tracks.

## Usage

After adding your Segment snippet into your html, you'll need to include this package in order to be able to fire events.

`analytics` will be an object with the methods described [here](#events)

### Step 1: Copy the Snippet in your HTML

```html
<script>
  !function(){var analytics=window.analytics=window.analytics||[];if(!analytics.initialize)if(analytics.invoked)window.console&&console.error&&console.error("Segment snippet included twice.");else{analytics.invoked=!0;analytics.methods=["trackSubmit","trackClick","trackLink","trackForm","pageview","identify","reset","group","track","ready","alias","debug","page","once","off","on"];analytics.factory=function(t){return function(){var e=Array.prototype.slice.call(arguments);e.unshift(t);analytics.push(e);return analytics}};for(var t=0;t<analytics.methods.length;t++){var e=analytics.methods[t];analytics[e]=analytics.factory(e)}analytics.load=function(t,e){var n=document.createElement("script");n.type="text/javascript";n.async=!0;n.src="https://cdn.segment.com/analytics.js/v1/"+t+"/analytics.min.js";var a=document.getElementsByTagName("script")[0];a.parentNode.insertBefore(n,a);analytics._loadOptions=e};analytics.SNIPPET_VERSION="4.1.0";

  analytics.load("YOUR_WRITE_KEY");  // your write key must be set here
  }}();
</script>
```

### Step 2: Use

#### In your modern and beautiful JavaScript...

```js
import analytics from '@s-ui/segment-wrapper'
```

### In your monolithic JavaScript...

```js
// First load the UMD module.
<script src="https://unpkg.com/@s-ui/segment-wrapper/umd/index.js"></script>
<script>
  // Then trigger all the events you need referencing the right namespaced
  // object: `window.sui.analytics`. For more info see the "Events" section below.
  window.sui.analytics.identify('your user id', {});
  window.sui.analytics.track('your event', {});
  window.sui.analytics.reset();
</script>
```

### Step 3: Configure Segment Wrapper (optional)

You could put a special config in a the `window.__mpi` to change some behaviour of the wrapper. This config MUST somewhere before using the Segment Wrapper.

- `googleAdsPixelId`: _(optional)_ If set, pixel of Google Ads will be synchronized.
- `facebookPixelId`: _(optional)_ If set, pixel of Facebook will be synchronized.
- `defaultProperties`: _(optional)_ If set, properties will be merged and sent with every `track` and `page`. It's the ideal place to put the `site` and `vertical` info to make sure that static info will be sent along with all the tracking.
- `getCustomAdobeVisitorId`: _(optional)_ If set, the output of this function will be used as `marketingCloudVisitorId` in Adobe Analytics' integration. It must return a promise.
- `importAdobeVisitorId` _(optional)_ If set and `true`, Adobe Visitor API will be fetched from Segment Wrapper instead of relying on being loaded before from Tealium or other services. Right now, by default, this is `false` but in the next major this configuration will be `true` by default. If `getCustomAdobeVisitorId` is being used this will be ignored.
- `tcfTrackDefaultProperties` _(optional)_ If set, this property will be merged together with the default properties set to send with every tcf track event
- `hashedUserEmail`: _(optional)_ If set, this user email will be used for the Visitor API.
- `userEmail`: _(optional)_ If set, the `userEmail` will be hashed with md5 and used for the Visitor API. If `hashedUserEmail` is set, this property will be ignored.

Example:

```js
  window.__mpi = {
    segmentWrapper: {
      googleAdsPixelId: '1054970353',
      facebookPixelId: '448176625351232',
      defaultProperties: {
        site: 'fotocasa',
        vertical: 'realestate'
      },
      getCustomAdobeVisitorId: () => {
        const visitorId = // get your visitorId
        return Promise.resolve(visitorId)
      },
      tcfTrackDefaultProperties: {
        tcfSpecialProp: 'anyvalue'
      }
    }
  }
```

## Events

### Track - [docs](https://segment.com/docs/spec/track/)

```js
import analytics from '@s-ui/segment-wrapper'

analytics.track('CTA Clicked')

analytics.track('Registered', {
  plan: 'Pro Annual',
  accountType: 'Facebook'
})
```

### Page

Internally uses `Track` but changes the `referrer` everytime is called.

```js
import analytics from '@s-ui/segment-wrapper'

analytics.page('Home Viewed')

analytics.page('List Viewed', {
  property: 'HOUSE',
  transaction: 'SELL'
})
```

### Identify - [docs](https://segment.com/docs/spec/identify/)

```js
import analytics from '@s-ui/segment-wrapper'

analytics.identify('97980cfea0067', {
  name: 'Peter Gibbons',
  email: 'peter@initech.com',
  plan: 'premium',
  logins: 5
})
```

### Reset - [docs](https://segment.com/docs/sources/website/analytics.js/#reset-logout)

```js
import analytics from '@s-ui/segment-wrapper'

analytics.reset()
```

==> segment-wrapper-3.2.0.tgz: package/README.md <==
# Segment Wrapper [![Build Status](https://travis.mpi-internal.com/scmspain/frontend-all--segment-wrapper.svg?token=rg6VMzkvzMeJr1v4tr6s&branch=master)](https://travis.mpi-internal.com/scmspain/frontend-all--segment-wrapper) ![](https://img.shields.io/badge/automatic-release-brightgreen)

This package adds an abstraction layer on top of [segment.com](https://segment.com/)'s [javascript library](https://segment.com/docs/sources/website/analytics.js/) with some useful integrations and fixes that could be used across Adevinta Spain:

**Data Quality 📈**
- [x] Add `page` method that internally uses `track` but with the correct `referrer` property.
- [x] Send `user.id` and `anonymousId` on every track.

**Adobe Audience Manager DMP 🙋**
- [x] Integrates DMP and send `ssf` correct value depending on user's consents.
- [x] Sync Facebook and Google pixels (if you provide the needed config).
- [x] Persist pixels to sync in a stack, to be sure they're sent after navigation.
- [x] Send md5 hashed email with normalizations via `userEmail` or `hashedUserEmail` configs.

**Adobe Marketing Cloud Visitor Id ☁️**
- [x] Load *Adobe Visitor API* when needed (if flag `importAdobeVisitorId` is set to `true`, otherwise you should load `Visitor API` by your own to get the `mcvid`).
- [x] Fetch `marketingCloudVisitorId` and put in integrations object for every track.
- [x] Monkey patch `track` native Segment method to send `marketingCloudVisitorId` inside `context.integrations`.

**Consent Management Platform 🐾**
- [x] Automatic tracking of Consent Management Platform usage.
- [x] Send `gdpr_privacy` on `context` for for all tracking events. Expect values: `unknown`, `accepted` and `declined`. 

**Developer Experience 👩‍💻**
- [x] Always send `platform` property as `web`.
- [x] Allow to configure `window.__mpi.defaultProperties` to send these properties on all tracks.

## Usage

After adding your Segment snippet into your html, you'll need to include this package in order to be able to fire events.

`analytics` will be an object with the methods described [here](#events)

### Step 1: Copy the Snippet in your HTML

```html
<script>
  !function(){var analytics=window.analytics=window.analytics||[];if(!analytics.initialize)if(analytics.invoked)window.console&&console.error&&console.error("Segment snippet included twice.");else{analytics.invoked=!0;analytics.methods=["trackSubmit","trackClick","trackLink","trackForm","pageview","identify","reset","group","track","ready","alias","debug","page","once","off","on"];analytics.factory=function(t){return function(){var e=Array.prototype.slice.call(arguments);e.unshift(t);analytics.push(e);return analytics}};for(var t=0;t<analytics.methods.length;t++){var e=analytics.methods[t];analytics[e]=analytics.factory(e)}analytics.load=function(t,e){var n=document.createElement("script");n.type="text/javascript";n.async=!0;n.src="https://cdn.segment.com/analytics.js/v1/"+t+"/analytics.min.js";var a=document.getElementsByTagName("script")[0];a.parentNode.insertBefore(n,a);analytics._loadOptions=e};analytics.SNIPPET_VERSION="4.1.0";

  analytics.load("YOUR_WRITE_KEY");  // your write key must be set here
  }}();
</script>
```

### Step 2: Use

#### In your modern and beautiful JavaScript...

```js
import analytics from '@s-ui/segment-wrapper'
```

### In your monolithic JavaScript...

```js
// First load the UMD module.
<script src="https://unpkg.com/@s-ui/segment-wrapper/umd/index.js"></script>
<script>
  // Then trigger all the events you need referencing the right namespaced
  // object: `window.sui.analytics`. For more info see the "Events" section below.
  window.sui.analytics.identify('your user id', {});
  window.sui.analytics.track('your event', {});
  window.sui.analytics.reset();
</script>
```

### Step 3: Configure Segment Wrapper (optional)

You could put a special config in a the `window.__mpi` to change some behaviour of the wrapper. This config MUST somewhere before using the Segment Wrapper.

- `googleAdsPixelId`: _(optional)_ If set, pixel of Google Ads will be synchronized.
- `facebookPixelId`: _(optional)_ If set, pixel of Facebook will be synchronized.
- `defaultProperties`: _(optional)_ If set, properties will be merged and sent with every `track` and `page`. It's the ideal place to put the `site` and `vertical` info to make sure that static info will be sent along with all the tracking.
- `getCustomAdobeVisitorId`: _(optional)_ If set, the output of this function will be used as `marketingCloudVisitorId` in Adobe Analytics' integration. It must return a promise.
- `importAdobeVisitorId` _(optional)_ If set and `true`, Adobe Visitor API will be fetched from Segment Wrapper instead of relying on being loaded before from Tealium or other services. Right now, by default, this is `false` but in the next major this configuration will be `true` by default. If `getCustomAdobeVisitorId` is being used this will be ignored.
- `tcfTrackDefaultProperties` _(optional)_ If set, this property will be merged together with the default properties set to send with every tcf track event
- `hashedUserEmail`: _(optional)_ If set, this user email will be used for the Visitor API.
- `userEmail`: _(optional)_ If set, the `userEmail` will be hashed with md5 and used for the Visitor API. If `hashedUserEmail` is set, this property will be ignored.

Example:

```js
  window.__mpi = {
    segmentWrapper: {
      googleAdsPixelId: '1054970353',
      facebookPixelId: '448176625351232',
      defaultProperties: {
        site: 'fotocasa',
        vertical: 'realestate'
      },
      getCustomAdobeVisitorId: () => {
        const visitorId = // get your visitorId
        return Promise.resolve(visitorId)
      },
      tcfTrackDefaultProperties: {
        tcfSpecialProp: 'anyvalue'
      }
    }
  }
```

## Events

### Track - [docs](https://segment.com/docs/spec/track/)

```js
import analytics from '@s-ui/segment-wrapper'

analytics.track('CTA Clicked')

analytics.track('Registered', {
  plan: 'Pro Annual',
  accountType: 'Facebook'
})
```

### Page

Internally uses `Track` but changes the `referrer` everytime is called.

```js
import analytics from '@s-ui/segment-wrapper'

analytics.page('Home Viewed')

analytics.page('List Viewed', {
  property: 'HOUSE',
  transaction: 'SELL'
})
```

### Identify - [docs](https://segment.com/docs/spec/identify/)

```js
import analytics from '@s-ui/segment-wrapper'

analytics.identify('97980cfea0067', {
  name: 'Peter Gibbons',
  email: 'peter@initech.com',
  plan: 'premium',
  logins: 5
})
```

### Reset - [docs](https://segment.com/docs/sources/website/analytics.js/#reset-logout)

```js
import analytics from '@s-ui/segment-wrapper'

analytics.reset()
```
